@@ -1,6 +1,5 @@
 #' Get taxonomic names for a given taxonomic name query.
 #' 
-#' @import ritis
 #' @param query TSN number (taxonomic serial number).
 #' @param get The rank of the taxonomic name to get. 
 #' @return Taxonomic name for the searched taxon.
@@ -10,7 +9,8 @@
 #' @export
 itis_name <- function(query = NULL, get = NULL) 
 {
-	tsn <- get_tsn(query, searchtype="sciname")
-	tt <- getfullhierarchyfromtsn(tsn)
-	as.character(tt[tt$rankName == capwords(get, onlyfirst=T), "taxonName"])
+	# 	tsn <- get_tsn(query, searchtype="sciname")
+	# 	tt <- getfullhierarchyfromtsn(tsn)
+	# 	as.character(tt[tt$rankName == capwords(get, onlyfirst=T), "taxonName"])
+	message("itis_name is deprecated, use tax_name instead")
 }
\ No newline at end of file
