@@ -19,7 +19,7 @@
 tp_namedistributions <- function(id, format = 'json', output = 'df', key=NULL) 
 {
   url = 'http://services.tropicos.org/Name/'
-	key <- getkey(key, "tropicos")
+	key <- getkey(key, "tropicosApiKey")
   if (format == 'json') {
     urlget <- paste(url, id, '/Distributions?apikey=', key, '&format=json', sep="")
     message(urlget)
