@@ -4,7 +4,7 @@ context("itis_taxrank")
 temp <- itis_taxrank(query=202385)
 
 test_that("itis_taxrank returns the correct value", {
-	expect_that(temp, matches("Subspecies"))
+	expect_that(as.character(temp), matches("Subspecies"))
 })
 
 test_that("itis_taxrank returns the correct class", {
